caellion-python-commons: caellion.pycommons.codeanalysis.reports Namespace Reference

caellion-python-commons

Classes
caellion.pycommons.codeanalysis.reports Namespace Reference

This module provides utlilities related to creating Jenkins' warnings-ng-plugin-compatible reports from codeanalysis. More...

## Classes
class | ReportBuilder
| This class provides a set of methods to create reports that are compatible with Jenkins' warnings-ng plugin. More...

## Detailed Description

This module provides utlilities related to creating Jenkins' warnings-ng-plugin-compatible reports from codeanalysis.